@@ -2,10 +2,13 @@
 
 from mason import callbacks
 from mason import exceptions
+from mason import events
+from mason import middleware
 from mason import library
-from mason import io
 from mason import node
 from mason import port
+from mason import schema
+from mason import storage
 
 try:
     from importlib import metadata  # Python 3.8+
@@ -16,15 +19,20 @@ __version__ = metadata.version('mason-framework')
 
 Blueprint = node.Blueprint
 Library = library.Library
+Event = events.Event
+Dispatcher = middleware.Dispatcher
+Middleware = middleware.Middleware
 Node = node.Node
+NodeShape = schema.NodeShape
 Port = port.Port
 PortDirection = port.PortDirection
+PortVisibility = port.PortVisibility
+Storage = storage.Storage
 Signal = callbacks.Signal
 
-dump_library = io.dump_library
+getter = port.getter
 get_default_library = library.get_default_library
 inport = port.inport
-load_blueprint = io.load_blueprint
 nodify = node.nodify
 outport = port.outport
 slot = callbacks.slot
